@@ -22,11 +22,14 @@ OC.L10N.register(
     "Addressbook" : "Osoitekirja",
     "Groups" : "Ryhmät",
     "New contact" : "Uusi yhteystieto",
+    "No errors" : "Ei virheitä",
     "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
+    "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} virheellinen yhteystieto","{failedCount} virheellistä yhteystietoa"],
     "Select type" : "Valitse tyyppi",
     "Select Date" : "Valitse päivä",
     "Add contact in group" : "Lisää yhteystieto ryhmään",
     "No results" : "Ei tuloksia",
+    "Last modified" : "Viimeksi muokattu",
     "Select option" : "Valitse valinta",
     "Copy link" : "Kopioi linkki",
     "Copied" : "Kopioitu",
@@ -54,6 +57,7 @@ OC.L10N.register(
     "Last name" : "Sukunimi",
     "Display name" : "Näyttönimi",
     "Sort by {sorting}" : "Järjestysperuste {sorting}",
+    "Not grouped" : "Ei ryhmitelty",
     "Unable to create the contact." : "Yhteystiedon luominen ei onnistunut.",
     "Contact not found" : "Yhteytietoa ei löytynyt",
     "Nickname" : "Kutsumanimi",
@@ -111,6 +115,7 @@ OC.L10N.register(
     "Gender" : "Sukupuoli",
     "Female" : "Nainen",
     "Male" : "Mies",
+    "Unknown" : "Tuntematon",
     "An error occurred" : "Tapahtui virhe"
 },
 "nplurals=2; plural=(n != 1);");
