@@ -7,8 +7,14 @@ OC.L10N.register(
     "A contacts app for Nextcloud" : "En kontakt-app för Nextcloud",
     "Add new property" : "Lägg till nytt fält",
     "Choose property type" : "Välj typ",
+    "Add a new picture" : "Lägg till en ny bild",
     "Upload a new picture" : "Ladda upp en ny bild",
+    "Choose from files" : "Välj från filer",
+    "Delete picture" : "Radera bild",
+    "Download picture" : "Ladda ner bild",
     "Image is too big (max 1MB)." : "Bilden är för stor (max 1MB)",
+    "Pick an avatar" : "Välj en avatar",
+    "Error while processing the picture." : "Fel vid bearbetning av bilden.",
     "No contact selected" : "Ingen kontakt vald",
     "Select a contact on the list to begin" : "Välj en kontakt i listan för att börja",
     "Loading" : "Laddar",
@@ -19,11 +25,14 @@ OC.L10N.register(
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Den här kontakten är skrivskyddad. Du har inte behörighet att redigera den här kontakten.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du försökte redigera har ändrats. Uppdatera kontakten manuellt. Eventuella ytterligare ändringar kommer att kasseras.",
     "Download" : "Ladda ned",
+    "Generate QR Code" : "Generera QR-kod",
     "Delete" : "Radera",
     "Addressbook" : "Adressbok",
     "Groups" : "Grupper",
     "New contact" : "Ny kontakt",
     "Syntax error. Cannot open the contact." : "Syntaxfel. Kan inte öppna kontakten.",
+    "Deleting the contact in {countdown} seconds" : "Raderar kontakten om {countdown} sekunder",
+    "Done importing {total} contacts into" : "Klar med import av {totalt} kontakter till",
     "Importing {total} contacts into" : "Importerar {total} kontakter till",
     "No errors" : "Inga fel",
     "Open your browser console for more details" : "Öppna din webbläsarkonsol för mer information",
